# nn-names

A pure python package to generate random names using neural network

## Installation

You can install the package via pip:

```bash
pip install nn-names
```

## Usage

```python
from nn_names import generate_name

for _ in range(10):
    name = generate_name()
    print(name)

# Skay
# Wendr
# Pavie
# Axton
# Atto
# Inll
# Winaydn
# Gido
# Helanangel
# Xenrobel
```

## License

This project is licensed under the terms of the MIT license.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## Contact

If you want to contact me you can reach me at pradishbijukchhe@gmail.com.
